@@ -14,10 +14,9 @@ OpenAPI_events_subsc_req_data_t *OpenAPI_events_subsc_req_data_create(
     char *notif_corre_id
 )
 {
-    OpenAPI_events_subsc_req_data_t *events_subsc_req_data_local_var = OpenAPI_malloc(sizeof(OpenAPI_events_subsc_req_data_t));
-    if (!events_subsc_req_data_local_var) {
-        return NULL;
-    }
+    OpenAPI_events_subsc_req_data_t *events_subsc_req_data_local_var = ogs_malloc(sizeof(OpenAPI_events_subsc_req_data_t));
+    ogs_assert(events_subsc_req_data_local_var);
+
     events_subsc_req_data_local_var->events = events;
     events_subsc_req_data_local_var->notif_uri = notif_uri;
     events_subsc_req_data_local_var->req_qos_mon_params = req_qos_mon_params;
@@ -256,12 +255,12 @@ OpenAPI_events_subsc_req_data_t *OpenAPI_events_subsc_req_data_parseFromJSON(cJS
 
     events_subsc_req_data_local_var = OpenAPI_events_subsc_req_data_create (
         eventsList,
-        notif_uri ? ogs_strdup_or_assert(notif_uri->valuestring) : NULL,
+        notif_uri ? ogs_strdup(notif_uri->valuestring) : NULL,
         req_qos_mon_params ? req_qos_mon_paramsList : NULL,
         qos_mon ? qos_mon_local_nonprim : NULL,
         req_anis ? req_anisList : NULL,
         usg_thres ? usg_thres_local_nonprim : NULL,
-        notif_corre_id ? ogs_strdup_or_assert(notif_corre_id->valuestring) : NULL
+        notif_corre_id ? ogs_strdup(notif_corre_id->valuestring) : NULL
     );
 
     return events_subsc_req_data_local_var;
