@@ -1,7 +1,7 @@
 /*
  * usage_mon_level.h
  *
- *
+ * 
  */
 
 #ifndef _OpenAPI_usage_mon_level_H_
@@ -12,6 +12,7 @@
 #include "../include/list.h"
 #include "../include/keyValuePair.h"
 #include "../include/binary.h"
+#include "usage_mon_level_any_of.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -22,7 +23,7 @@ typedef struct OpenAPI_usage_mon_level_s {
 } OpenAPI_usage_mon_level_t;
 
 OpenAPI_usage_mon_level_t *OpenAPI_usage_mon_level_create(
-    );
+);
 void OpenAPI_usage_mon_level_free(OpenAPI_usage_mon_level_t *usage_mon_level);
 OpenAPI_usage_mon_level_t *OpenAPI_usage_mon_level_parseFromJSON(cJSON *usage_mon_levelJSON);
 cJSON *OpenAPI_usage_mon_level_convertToJSON(OpenAPI_usage_mon_level_t *usage_mon_level);
