@@ -155,13 +155,12 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
 
         CASE(OGS_SBI_SERVICE_NAME_NPCF_SMPOLICYCONTROL)
             stream = e->sbi.data;
-            ogs_assert(stream);
-
             state = e->sbi.state;
 
             SWITCH(sbi_message->h.resource.component[0])
             CASE(OGS_SBI_RESOURCE_NAME_SM_POLICIES)
                 if (!sbi_message->h.resource.component[1]) {
+                    ogs_assert(stream);
                     if (sbi_message->res_status !=
                             OGS_SBI_HTTP_STATUS_CREATED) {
                         strerror = ogs_msprintf(
@@ -193,10 +192,11 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
                             ogs_assert(strerror);
 
                             ogs_error("%s", strerror);
-                            ogs_assert(true ==
-                                ogs_sbi_server_send_error(stream,
-                                    sbi_message->res_status,
-                                    sbi_message, strerror, NULL));
+                            if (stream)
+                                ogs_assert(true ==
+                                    ogs_sbi_server_send_error(stream,
+                                        sbi_message->res_status,
+                                        sbi_message, strerror, NULL));
                             ogs_free(strerror);
                             break;
                         }
@@ -213,10 +213,11 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
                         ogs_assert(strerror);
 
                         ogs_error("%s", strerror);
-                        ogs_assert(true ==
-                            ogs_sbi_server_send_error(stream,
-                                OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                                sbi_message, strerror, NULL));
+                        if (stream)
+                            ogs_assert(true ==
+                                ogs_sbi_server_send_error(stream,
+                                    OGS_SBI_HTTP_STATUS_BAD_REQUEST,
+                                    sbi_message, strerror, NULL));
                         ogs_free(strerror);
                     END
                 }
@@ -240,7 +241,7 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
         CASE(OGS_SBI_SERVICE_NAME_NAMF_COMM)
             SWITCH(sbi_message->h.resource.component[0])
             CASE(OGS_SBI_RESOURCE_NAME_UE_CONTEXTS)
-                smf_namf_comm_handler_n1_n2_message_transfer(
+                smf_namf_comm_handle_n1_n2_message_transfer(
                         sess, e->sbi.state, sbi_message);
                 break;
 
@@ -280,6 +281,16 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
             }
             break;
 
+        case OGS_NAS_5GS_PDU_SESSION_MODIFICATION_REQUEST:
+            rv = gsm_handle_pdu_session_modification_request(sess, stream,
+                    &nas_message->gsm.pdu_session_modification_request);
+            if (rv != OGS_OK) {
+                ogs_error("[%s:%d] Cannot handle NAS message",
+                        smf_ue->supi, sess->psi);
+                OGS_FSM_TRAN(s, smf_gsm_state_exception);
+            }
+            break;
+
         case OGS_NAS_5GS_PDU_SESSION_MODIFICATION_COMPLETE:
             ogs_assert(true == ogs_sbi_send_http_status_no_content(stream));
             break;
@@ -362,6 +373,16 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
             }
             break;
 
+        case OpenAPI_n2_sm_info_type_PDU_RES_SETUP_FAIL:
+            rv = ngap_handle_pdu_session_resource_setup_unsuccessful_transfer(
+                    sess, stream, pkbuf);
+            if (rv != OGS_OK) {
+                ogs_error("[%s:%d] Cannot handle NGAP message",
+                        smf_ue->supi, sess->psi);
+                OGS_FSM_TRAN(s, smf_gsm_state_exception);
+            }
+            break;
+
         case OpenAPI_n2_sm_info_type_PDU_RES_MOD_RSP:
             rv = ngap_handle_pdu_session_resource_modify_response_transfer(
                     sess, stream, pkbuf);
@@ -375,8 +396,26 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
         case OpenAPI_n2_sm_info_type_PDU_RES_REL_RSP:
             ngap_state = sess->ngap_state.pdu_session_resource_release;
 
-            if (ngap_state == SMF_NGAP_STATE_DELETE_TRIGGER_UE_REQUESTED) {
+            if (ngap_state == SMF_NGAP_STATE_NONE) {
+                strerror = ogs_msprintf(
+                        "[%s:%d] No PDUSessionResourceReleaseRequest",
+                        smf_ue->supi, sess->psi);
+                ogs_assert(strerror);
+
+                ogs_error("%s", strerror);
+                ogs_assert(true ==
+                    ogs_sbi_server_send_error(stream,
+                        OGS_SBI_HTTP_STATUS_BAD_REQUEST, NULL, strerror, NULL));
+                ogs_free(strerror);
+
+                OGS_FSM_TRAN(s, smf_gsm_state_exception);
+
+            } else if (
+                ngap_state == SMF_NGAP_STATE_DELETE_TRIGGER_UE_REQUESTED ||
+                ngap_state == SMF_NGAP_STATE_DELETE_TRIGGER_PCF_INITIATED) {
+
                 ogs_assert(true == ogs_sbi_send_http_status_no_content(stream));
+
             } else if (ngap_state ==
                     SMF_NGAP_STATE_ERROR_INDICATION_RECEIVED_FROM_5G_AN) {
                 smf_n1_n2_message_transfer_param_t param;
