@@ -67,7 +67,7 @@ static void test1_func(abts_case *tc, void *data)
     test_ue->k_string = "465b5ce8b199b49faa5f0a2ee238a6bc";
     test_ue->opc_string = "e8ed289deba952e4283b54e88e6183ca";
 
-    sess = test_sess_add_by_apn(test_ue, "internet");
+    sess = test_sess_add_by_apn(test_ue, "internet", OGS_GTP_RAT_TYPE_EUTRAN);
     ogs_assert(sess);
 
     /* eNB connects to MME */
@@ -100,6 +100,8 @@ static void test1_func(abts_case *tc, void *data)
             0, sizeof(sess->pdn_connectivity_param));
     sess->pdn_connectivity_param.eit = 1;
     sess->pdn_connectivity_param.pco = 1;
+    sess->pdn_connectivity_param.request_type =
+        OGS_NAS_EPS_REQUEST_TYPE_INITIAL;
     esmbuf = testesm_build_pdn_connectivity_request(sess);
     ABTS_PTR_NOTNULL(tc, esmbuf);
 
@@ -201,6 +203,8 @@ static void test1_func(abts_case *tc, void *data)
     /* Send Attach Request */
     sess->pdn_connectivity_param.eit = 1;
     sess->pdn_connectivity_param.pco = 1;
+    sess->pdn_connectivity_param.request_type =
+        OGS_NAS_EPS_REQUEST_TYPE_INITIAL;
     esmbuf = testesm_build_pdn_connectivity_request(sess);
     ABTS_PTR_NOTNULL(tc, esmbuf);
 
@@ -273,6 +277,8 @@ static void test1_func(abts_case *tc, void *data)
     /* Send Attach Request - No Integrity */
     sess->pdn_connectivity_param.eit = 1;
     sess->pdn_connectivity_param.pco = 1;
+    sess->pdn_connectivity_param.request_type =
+        OGS_NAS_EPS_REQUEST_TYPE_INITIAL;
     esmbuf = testesm_build_pdn_connectivity_request(sess);
     ABTS_PTR_NOTNULL(tc, esmbuf);
 
@@ -344,6 +350,8 @@ static void test1_func(abts_case *tc, void *data)
     /* Send Attach Request - No Integrity */
     sess->pdn_connectivity_param.eit = 1;
     sess->pdn_connectivity_param.pco = 1;
+    sess->pdn_connectivity_param.request_type =
+        OGS_NAS_EPS_REQUEST_TYPE_INITIAL;
     esmbuf = testesm_build_pdn_connectivity_request(sess);
     ABTS_PTR_NOTNULL(tc, esmbuf);
 
